@@ -1,6 +1,4 @@
-__author__ = 'mmatosevic'
-
-from infobip_api_python_client.clients import get_received_messages
+from infobip.clients import get_received_messages
 from __init__ import configuration
 
 get_delivery_reports_client = get_received_messages(configuration)
